==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Čas za overitev je potekel</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk je v rabi. Trenutno ga ni mogoče odklopiti</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk deluje in ga trenutno ni mogoče varno odstraniti</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Naprava je v rabi in je trenutno ni mogoče izvreči</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Naprava je v rabi n je trenutno ni mogoče odstraniti</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Glasnost</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-upravitelj-datotek</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Naprava ni bila varno odstranjena</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Klikni &quot;Varno odstrani&quot; in nato odstranite</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Naprava je v rabi in je trenutno ni mogoče izvreči</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Naprava je v rabi n je trenutno ni mogoče odstraniti</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Naprave ni mogoče odklopiti</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Disk je priklopil uporabnik &quot;%1&quot;, ne morete ga odklopiti.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Priklopljene naprave ni mogoče najti</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Diski</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Izvrzi vse</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Naprava je bila varno odstranjena</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Zavrnjen dostop</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nimate dovoljenja za dostopanje do te mape</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Preverjanje naprave. Zaustavim?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.5.10.orig.tar.xz: dde-file-manager-5.5.10/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Čas za overitev je potekel</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk je v rabi. Trenutno ga ni mogoče odklopiti</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk deluje in ga trenutno ni mogoče varno odstraniti</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Naprava je v rabi in je trenutno ni mogoče izvreči</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Naprava je v rabi n je trenutno ni mogoče odstraniti</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Glasnost</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-upravitelj-datotek</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Naprava ni bila varno odstranjena</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Klikni &quot;Varno odstrani&quot; in nato odstranite</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Naprave ni mogoče odklopiti</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Disk je priklopil uporabnik &quot;%1&quot;, ne morete ga odklopiti.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Priklopljene naprave ni mogoče najti</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Diski</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Izvrzi vse</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Naprava je bila varno odstranjena</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Zavrnjen dostop</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nimate dovoljenja za dostopanje do te mape</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Preverjanje naprave. Zaustavim?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potrdi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Zaustavi</translation>
    </message>
</context>
</TS>
